@@ -1,6 +1,7 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) 2013  Adrien Devresse <adrien.devresse@cern.ch>, CERN
+ * Copyright (C) CERN 2013
+ * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +19,6 @@
  *
 */
 
-
 #ifndef DAVIX_TOOL_UTIL_HPP
 #define DAVIX_TOOL_UTIL_HPP
 
@@ -37,6 +37,8 @@ dav_ssize_t writeToFd(int fd, const std::string & str);
 
 int configureAuth(OptParams & opts);
 
+bool checkProtocolSanity(OptParams &opts, const std::string &url, DavixError **err);
+
 void configureContext(Context &context, const OptParams & opts);
 
 void errorPrint(DavixError ** err);
@@ -78,6 +80,14 @@ void printProgressBar(int out_fd, int percent, dav_ssize_t bytes_transfered, dav
 
 int configureMonitorCB(OptParams & opts, Transfer::Type type);
 
+void tokeniseUrl(std::string url, std::deque<std::string>& dirVec);
+
+// mkdir -p, discard front and back entries if trim is true
+int mkdirP(std::string dirPath, bool trim);
+int mkdirP(std::deque<std::string>& dirVec, bool trim);
+
+void batchTransferMonitor(std::string dirPath, std::string msg, int entryCount, int totalEntry);
+
 }
 }
 
